Skip to main contentModule task
Source pub use crate::api::ExternalEventResult;
- ActivityContext
- Context provided to activity functions during execution.
- ActivityOptions
- Options for scheduling an activity call from an orchestrator.
- CompletableTask
- A task that can be completed by the orchestration executor.
- OrchestrationContext
- The orchestration context provided to orchestrator functions.
- SubOrchestratorOptions
- Options for scheduling a sub-orchestration call from an orchestrator.
- WhenAllTask
- A future that completes when all tasks complete, or fails if any task fails.
Returns a
Vec of JSON-serialised results on success. - WhenAnyTask
- A future that completes when ANY task completes (success or failure).
Returns the index of the first completed task.
- TaskResult
- The result of a completed task.
- when_all
- Wait for all tasks to complete. Fails if any task fails.
- when_any
- Wait for any task to complete. Returns the index of the first completed task.