pub struct CompletableTask { /* private fields */ }Expand description
A task that can be completed by the orchestration executor.
This is the primary awaitable type used by orchestrator functions. During replay, tasks that already completed return their results immediately. New tasks suspend execution until completed by the executor.
Implementations
Sourceimpl CompletableTask
impl CompletableTask
pub fn new() -> Self
Sourcepub fn fail(&self, details: FailureDetails)
pub fn fail(&self, details: FailureDetails)
Fail the task with failure details.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Check if the task is complete (success or failure).
Sourcepub fn get_result(&self) -> Option<TaskResult>
pub fn get_result(&self) -> Option<TaskResult>
Get the result, if complete. Returns None if not yet complete.